==> marray_1.24.0.zip: marray/doc/marrayNorm.R <==
###################################################
### chunk number 1: 
###################################################
library("marray", verbose=FALSE)
data(swirl)
maPlate(swirl)<-maCompPlate(swirl,n=384)


###################################################
### chunk number 2: 
###################################################
swirl.norm <- maNorm(swirl, norm="p")
summary(swirl.norm)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## swirl.norm1 <- maNorm(swirl, norm="p")
## swirl.norm2 <- maNormScale(swirl.norm1, norm="p")


###################################################
### chunk number 4: maBoxplot1pre
###################################################
boxplot(swirl[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: pre--normalization")


###################################################
### chunk number 5: maBoxplot2pre
###################################################
boxplot(swirl, yvar="maM", main="Swirl arrays: pre--normalization")


###################################################
### chunk number 6: maBoxplot1post
###################################################
boxplot(swirl.norm[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: post--normalization")


###################################################
### chunk number 7: maBoxplot2post
###################################################
boxplot(swirl.norm, yvar="maM", main="Swirl arrays: post--normalization")


###################################################
### chunk number 8: maPlot1pre
###################################################
plot(swirl[,3], main="Swirl array 93: pre--normalization MA--plot")


###################################################
### chunk number 9: maPlot1post
###################################################
plot(swirl.norm[,3], main="Swirl array 93: post--normalization MA--plot")

==> marray_1.28.0.zip: marray/doc/marrayNorm.R <==
###################################################
### chunk number 1: 
###################################################
#line 294 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
library("marray", verbose=FALSE)
data(swirl)
maPlate(swirl)<-maCompPlate(swirl,n=384)


###################################################
### chunk number 2: 
###################################################
#line 315 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
swirl.norm <- maNorm(swirl, norm="p")
summary(swirl.norm)


###################################################
### chunk number 3:  eval=FALSE
###################################################
## #line 341 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
## swirl.norm1 <- maNorm(swirl, norm="p")
## swirl.norm2 <- maNormScale(swirl.norm1, norm="p")


###################################################
### chunk number 4: maBoxplot1pre
###################################################
#line 388 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
boxplot(swirl[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: pre--normalization")


###################################################
### chunk number 5: maBoxplot2pre
###################################################
#line 392 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
boxplot(swirl, yvar="maM", main="Swirl arrays: pre--normalization")


###################################################
### chunk number 6: maBoxplot1post
###################################################
#line 396 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
boxplot(swirl.norm[,3], xvar="maPrintTip", yvar="maM", main="Swirl array 93: post--normalization")


###################################################
### chunk number 7: maBoxplot2post
###################################################
#line 400 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
boxplot(swirl.norm, yvar="maM", main="Swirl arrays: post--normalization")


###################################################
### chunk number 8: maPlot1pre
###################################################
#line 404 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
plot(swirl[,3], main="Swirl array 93: pre--normalization MA--plot")


###################################################
### chunk number 9: maPlot1post
###################################################
#line 408 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpiDtaei/R.INSTALL55732dc1/marray/inst/doc/marrayNorm.Rnw"
plot(swirl.norm[,3], main="Swirl array 93: post--normalization MA--plot")
